@@ -195,7 +195,7 @@ if options.output_type == 'rpm'
           else
             fail "Unrecognized el os version #{options.os_version}"
           end
-        when 6..7
+        when 7
           'java-1.8.0-openjdk-headless'
         else
           fail "Unknown Puppet Platform Version #{options.platform_version}"
@@ -219,8 +219,12 @@ if options.output_type == 'rpm'
         case options.platform_version
         when 8
           'java-11-openjdk-headless'
-        when 6..7
-          'java-1_8_0-openjdk-headless'
+        when 7
+          if options.os_version > 12
+            'java-11-openjdk-headless'
+          else
+            'java-1_8_0-openjdk-headless'
+          end
         else
           fail "Unknown Puppet Platform Version #{options.platform_version}"
         end
@@ -324,21 +328,7 @@ elsif options.output_type == 'deb'
   end
 
   if ! options.is_pe
-    options.java =
-      case options.platform_version
-      when 8
-        if options.dist =~ /buster|bullseye|bookworm|bionic|focal|jammy/
-          'openjdk-17-jre-headless | openjdk-11-jre-headless'
-        end
-      when 6..7
-        if options.dist =~ /buster|bullseye/ # debian 10+ uses java11
-          'openjdk-11-jre-headless'
-        else
-          'openjdk-8-jre-headless'
-        end
-      else
-        fail "Unknown Puppet Platform Version #{options.platform_version}"
-      end
+    options.java = 'openjdk-17-jre-headless | openjdk-11-jre-headless'
   end
 
   fpm_opts << '--deb-build-depends cdbs'
